From: Maciek Machnikowski <[email protected]>

The PHY on E825-C requires recalibration after large jumps of the
system time. Add missing PHY recalibration also on E825-C.

Fixes: 7cab44f1c35f ("ice: Introduce ETH56G PHY model for E825C products")
Signed-off-by: Maciek Machnikowski <[email protected]>
Signed-off-by: Tony Nguyen <[email protected]>
---
 drivers/net/ethernet/intel/ice/ice_ptp.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/drivers/net/ethernet/intel/ice/ice_ptp.c 
b/drivers/net/ethernet/intel/ice/ice_ptp.c
index 84b99cfc5675..bf625b9f4991 100644
--- a/drivers/net/ethernet/intel/ice/ice_ptp.c
+++ b/drivers/net/ethernet/intel/ice/ice_ptp.c
@@ -1956,8 +1956,9 @@ ice_ptp_settime64(struct ptp_clock_info *info, const 
struct timespec64 *ts)
        /* Reenable periodic outputs */
        ice_ptp_enable_all_perout(pf);
 
-       /* Recalibrate and re-enable timestamp blocks for E822/E823 */
-       if (hw->mac_type == ICE_MAC_GENERIC)
+       /* Recalibrate and re-enable timestamp blocks for E822/E823/E825-C */
+       if (hw->mac_type == ICE_MAC_GENERIC ||
+           hw->mac_type == ICE_MAC_GENERIC_3K_E825)
                ice_ptp_restart_all_phy(pf);
 exit:
        if (err) {
-- 
2.47.1

Reply via email to